@@ -9,9 +9,10 @@ class Networks:
     renaming and removing them by ID.
     """
 
-    def __init__(self, headers, api_url):
+    def __init__(self, headers, api_url, region):
+        param = "?region={region}".format(region=region) if region else ''
         self.headers = headers
-        self.url = 'https://{}/v2/networks'.format(api_url)
+        self.url = '{api_url}/v2/networks{param}'.format(api_url=api_url, param=param)
 
     def create(self, label: str) -> dict:
         """
