@@ -10,7 +10,7 @@ class Quota:
 
     def __init__(self, headers, api_url):
         self.headers = headers
-        self.url = 'https://{}/v2/quota'.format(api_url)
+        self.url = '{}/v2/quota'.format(api_url)
 
     def get(self) -> dict:
         """
