@@ -13,7 +13,7 @@ class Regions:
 
     def __init__(self, headers, api_url):
         self.headers = headers
-        self.url = 'https://{}/v2/regions'.format(api_url)
+        self.url = '{}/v2/regions'.format(api_url)
 
     def search(self, filter: str = None) -> dict:
         """
