@@ -12,7 +12,7 @@ class Size:
 
     def __init__(self, headers, api_url):
         self.headers = headers
-        self.url = 'https://{}/v2/sizes'.format(api_url)
+        self.url = '{}/v2/sizes'.format(api_url)
 
     def search(self, filter: str = None) -> dict:
         """
