@@ -1,6 +1,12 @@
 """
 File to handle all utils
 """
+from __future__ import print_function
+import sys
+
+
+def print_err(*args, **kwargs):
+    print(*args, file=sys.stderr, **kwargs)
 
 
 def filter_list(data: dict, filter_by: str) -> list:
