@@ -12,9 +12,10 @@ class Volumes:
     As volume storage is chargeable, at any time these can be deleted.
     """
 
-    def __init__(self, headers, api_url):
+    def __init__(self, headers, api_url, region):
+        param = "?region={region}".format(region=region) if region else ''
         self.headers = headers
-        self.url = 'https://{}/v2/volumes'.format(api_url)
+        self.url = '{api_url}/v2/volumes{param}'.format(api_url=api_url, param=param)
 
     def create(self, name: str, size_gb: str, bootable: str = 'false') -> dict:
         """
